使用 python3  + click  编写的个人常用的工具  

* 简易管理服务器
* 在线备份配置 tools 配置  
* 建立临时http共享目录
* 获取设备基本信息 
* 管理常用脚本   
* 测试socket是否能连通   


```shell script
# ubuntu 使用python3 版本的pip 名字默认为pip3 
#安装
pip3 install jiuming-tools
#更新
pip3 install --upgrade jiuming-tools 
# 使用
m
#启用自动补全:
#bash:在.bashrc末尾添加 eval "$(_M_COMPLETE=source m)"
#zsh:在.zshrc末尾添加 eval "$(_M_COMPLETE=source_zsh m)"
```